#!/bin/bash
# System Center Operations Scripts
# Vanessa V. Revised 10/5/11
# Collects statistic and usage information from the node for SC

# Get our basic server information

IP=$(cat /var/cpanel/mainip)
LAN=$(/sbin/ifconfig |grep -E '10\.128\.|192\.168\.|10\.127\.' | awk '{ print $2 }' |cut -d: -f2)
MAC=$(/sbin/ifconfig |grep eth0 | head -1 |awk '{print $5}')
DATE=$(date +%s)

OUTFILE="/opt/scops/out/statrep.${IP}"

[ -d  /opt/scops/out/ ] || mkdir -p /opt/scops/out/
chown -R scops:scops /opt/scops/
rm -f /opt/scops/out/statrep*

# Record the RAID controller type

RAIDCTRL=$(/sbin/lspci -vv 2>/dev/null | grep RAID)
if grep '5i' >/dev/null <<< "$RAIDCTRL";then
    RAIDT="5i"
elif grep -q 'controller 5' <<< "$RAIDCTRL"; then
    RAIDT="5"
elif grep -q "controller 4" <<< "$RAIDCTRL"; then
    RAIDT="4"
elif grep -q "4/Di" <<< "$RAIDCTRL"; then
    RAIDT="4/Di"
elif grep -q "5/i" <<< "$RAIDCTRL"; then
    RAIDT="5/i"
elif grep -q "6/i" <<< "$RAIDCTRL"; then
    RAIDT="6/i"
elif grep -q "1078" <<< "$RAIDCTRL"; then
    RAIDT="1078"
elif grep -q "2108" <<< "$RAIDCTRL"; then
    RAIDT="2108"
elif grep -q "9260" <<< "$RAIDCTRL"; then
    RAIDT="9260"
elif grep -q "2208" <<< "$RAIDCTRL"; then
    RAIDT="2208"
elif grep -q "3108" <<< "$RAIDCTRL"; then
    RAIDT="3108"
else
    RAIDT="??"
fi


# CPU Type & Ct
CPUCOUNT=$(grep 'model name' /proc/cpuinfo | sed -e 's/.*: //' | wc -l )
CPU=$(grep 'model name' /proc/cpuinfo | sed -e 's/.*: //' | sed -e 's/(R)//g' -e 's/CPU//g' |uniq | awk '$1=$1')

# OS/arch
OS=$(/opt/imh-python/bin/python3 -c '
import distro
name = distro.id()
if name == "cloudlinux":
    name = "CloudLinux"
print(name, distro.version())
')

# Memory

TOTALMEM=0
while read -r row; do
    if grep -q 'No Module Installed' <<< "${row}"; then
        continue
    fi

    unit=$(awk '{print $3}' <<< "${row}" )
    size=$(awk '{print $2}' <<< "${row}" )

    if [[ "${unit}" =~ MB ]]; then
        size=$(( size / 1024 ))
    fi
    TOTALMEM=$(( TOTALMEM + size ))
done < <( dmidecode -t memory | grep -P "^\tSize:" )

TOTALSW=$(awk '/SwapTotal/ {print $2}' /proc/meminfo)
MEMT=$(( TOTALMEM ))
MEMT=$(echo $MEMT |sed 's/$/G/g')
MEMS=$(( TOTALSW / 1000000 ))
MEMS=$(echo $MEMS |sed 's/$/G/g')


# disk

if df -h /home &>/dev/null; then
    DISK=$(df -h /home |awk '/\// {print $5}')
else
    DISK=$(df -h / |awk '/\// {print $5}')
fi

if df -h /home2 &>/dev/null; then
    DISK2=$(df -h /home2 |awk '/\// {print $5}')
else
    DISK2="NA"
fi

if df -h /home3 &>/dev/null; then
    DISK3=$(df -h /home3 |awk '/\// {print $5}')
else
    DISK3="NA"
fi

if df -h /home4 &>/dev/null; then
    DISK4=$(df -h /home4 |awk '/\// {print $5}')
else
    DISK4="NA"
fi

# FS Type
device=$(df -h '/' | awk '/\// {print $1}')

if file -sL "$device" | grep -q ext3; then
    FS="ext3"
else
    FS="ext4"
fi

# SSD check
if /opt/MegaRAID/MegaCli/MegaCli64 -LdPdInfo -aALL -NoLog 2>/dev/null | grep -q 'Solid State'; then
    SSD=1
else
    SSD=0
fi

# NVMe check
if ls /dev/nvme*; then
    NVME=1;
    SSD=0;
else
    NVME=0;
fi

# cPanel check
CPANEL=$(cat /usr/local/cpanel/version)

# service tag

TAG=$(/usr/sbin/dmidecode  |grep "Serial Number" | head -1 |awk '{print $3}')

MODEL=$(/usr/sbin/dmidecode |grep "Product Name" | head -1 | awk '{print $3,$4}' |awk '$1=$1')

# user count
TOTALUSER=$(/bin/ls -1 -A /var/cpanel/users/ |wc -l)
SUSPENDED=$(/bin/ls -1 -A /var/cpanel/suspended/ |grep -c -v '\.lock')
RESELLERS=$(wc -l /var/cpanel/resellers  |awk '{print $1 - 2}')

# php version and api
PHPVER=$(/usr/local/bin/php -r 'echo phpversion();')

if [ -e /opt/suphp/etc/suphp.conf ]; then
    SAPI=CGI
elif hostname --short | grep -qP '^(ec|ams)?ngx(dev)?\d+'; then
    SAPI=FPM
else
    SAPI=DSO
fi

# EasyApache version
if [ -f /etc/cpanel/ea4/is_ea4 ] ; then
    EA=EA4
else
    EA=EA3
fi

# apache version
if [ "$EA" == "EA4" ]; then
    APACHE=$(/usr/sbin/httpd -v | awk '/version/ {print $3 $4}'| sed -e 's/Apache\///' -e 's/(Unix)//' | cut -d '(' -f1)
else
    APACHE=$(/usr/local/apache/bin/httpd -v | awk '/version/ {print $3 $4}'|sed -e 's/Apache\///' -e 's/(Unix)//' | cut -d '(' -f1)
fi

DOMAINS=$(wc -l /etc/userdomains | awk '{ print $1 }')

MYSQL=$(mysql -V |awk '{print $5}' | sed -e 's/,//')

TAG=$(/usr/sbin/dmidecode |grep "Serial" |awk '{print $3}' |head -2 |tail -1)

# Grab a list of alternate shared IPs
if [ -e /var/cpanel/mainips/root ];then
    # prevent grep -vP later from interpreting '.' as a wildcard by escaping them
    GRP_IP=$(echo "$IP" | sed 's/\./\\./g')
    ALT_IPS=$(grep -vP "\b${GRP_IP}\b" /var/cpanel/mainips/root | sort -n | tr  "\n" " ")
fi

# Dump all this to the ops file

# echo "server,$SERVER" >> "$OUTFILE"
# echo "mainip,$IP" >> "$OUTFILE"

cat <<EOF > "$OUTFILE"
date,$DATE
raid,$RAIDT
lan,$LAN
mac,$MAC
cpu,$CPU
cpuct,$CPUCOUNT
os,$OS
arch,$PLATFORM
memory,$MEMT + $MEMS
home,$DISK
home2,$DISK2
home3,$DISK3
home4,$DISK4
cpanel,$CPANEL
totaluser,$TOTALUSER
suspended,$SUSPENDED
res,$RESELLERS
phpver,$PHPVER
phpapi,$SAPI
apache,$APACHE
domains,$DOMAINS
ea,$EA
mysqlv,$MYSQL
tag,$TAG
model,$MODEL
altips,$ALT_IPS
ssd,$SSD
fs,$FS
nvme,$NVME
EOF

chown scops:scops "$OUTFILE"
